@@ -4,12 +4,13 @@ use aes::{
     Aes128, Aes128Ctr, Aes256, Aes256Ctr,
 };
 use block_modes::{block_padding::Pkcs7, BlockMode, Cbc};
+#[cfg(target_arch = "wasm32")]
 use wasm_bindgen::{prelude::*, throw_str};
 
-#[wasm_bindgen]
+#[cfg_attr(all(target_arch = "wasm32", feature = "wasm-bindgen-encryption"), wasm_bindgen)]
 pub struct AES {}
 
-#[wasm_bindgen]
+#[cfg_attr(all(target_arch = "wasm32", feature = "wasm-bindgen-encryption"), wasm_bindgen)]
 #[allow(non_camel_case_types)]
 #[derive(Debug, Clone, Copy)]
 pub enum AESAlgorithms {
@@ -22,8 +23,8 @@ pub enum AESAlgorithms {
 impl AES {
     pub fn encrypt_impl(key: &[u8], iv: &[u8], message: &[u8], algo: AESAlgorithms) -> Result<Vec<u8>, BSVErrors> {
         let result = match algo {
-            AESAlgorithms::AES128_CBC => Cbc::<Aes128, Pkcs7>::new_from_slices(key, iv)?.encrypt_vec(&message),
-            AESAlgorithms::AES256_CBC => Cbc::<Aes256, Pkcs7>::new_from_slices(key, iv)?.encrypt_vec(&message),
+            AESAlgorithms::AES128_CBC => Cbc::<Aes128, Pkcs7>::new_from_slices(key, iv)?.encrypt_vec(message),
+            AESAlgorithms::AES256_CBC => Cbc::<Aes256, Pkcs7>::new_from_slices(key, iv)?.encrypt_vec(message),
             AESAlgorithms::AES128_CTR => AES::aes_ctr::<Aes128Ctr>(key, iv, message),
             AESAlgorithms::AES256_CTR => AES::aes_ctr::<Aes256Ctr>(key, iv, message),
         };
@@ -38,7 +39,6 @@ impl AES {
             AESAlgorithms::AES128_CTR => AES::aes_ctr::<Aes128Ctr>(key, iv, message),
             AESAlgorithms::AES256_CTR => AES::aes_ctr::<Aes256Ctr>(key, iv, message),
         };
-
         Ok(result)
     }
 
@@ -52,21 +52,21 @@ impl AES {
 }
 
 #[cfg(target_arch = "wasm32")]
-#[wasm_bindgen]
+#[cfg_attr(all(target_arch = "wasm32", feature = "wasm-bindgen-encryption"), wasm_bindgen)]
 impl AES {
-    #[wasm_bindgen(js_name = encrypt)]
+    #[cfg_attr(all(target_arch = "wasm32", feature = "wasm-bindgen-encryption"), wasm_bindgen(js_name = encrypt))]
     pub fn encrypt(key: &[u8], iv: &[u8], message: &[u8], algo: AESAlgorithms) -> Result<Vec<u8>, JsValue> {
         match AES::encrypt_impl(key, iv, message, algo) {
             Ok(v) => Ok(v),
-            Err(e) => throw_str(&e.to_string()),
+            Err(e) => Err(JsValue::from_str(&e.to_string())),
         }
     }
 
-    #[wasm_bindgen(js_name = decrypt)]
+    #[cfg_attr(all(target_arch = "wasm32", feature = "wasm-bindgen-encryption"), wasm_bindgen(js_name = decrypt))]
     pub fn decrypt(key: &[u8], iv: &[u8], message: &[u8], algo: AESAlgorithms) -> Result<Vec<u8>, JsValue> {
         match AES::decrypt_impl(key, iv, message, algo) {
             Ok(v) => Ok(v),
-            Err(e) => throw_str(&e.to_string()),
+            Err(e) => Err(JsValue::from_str(&e.to_string())),
         }
     }
 }
