@@ -1,21 +1,24 @@
-#![feature(trait_alias)]
 #![cfg_attr(not(target_arch = "wasm32"), allow(dead_code, unused_imports))]
 
+#[cfg(target_arch = "wasm32")]
+use wasm_bindgen::prelude::*;
+
+#[cfg(target_arch = "wasm32")]
+#[wasm_bindgen(js_name=configureStacktrace)]
+pub fn configure_stacktrace() {
+    console_error_panic_hook::set_once();
+}
+
 #[macro_use]
 extern crate num_derive;
 
-#[cfg(target_arch = "wasm32")]
-extern crate wee_alloc;
-#[cfg(target_arch = "wasm32")]
-#[global_allocator]
-static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
+pub mod chainparams;
+pub use chainparams::*;
 
 pub mod keypair;
-
 pub use keypair::*;
 
 pub mod signature;
-
 pub use signature::*;
 
 pub mod traits;
@@ -50,3 +53,6 @@ pub use crate::ecdsa::*;
 
 pub mod bsm;
 pub use bsm::*;
+
+pub mod ecies;
+pub use ecies::*;
